@@ -134,9 +134,7 @@ e_exchange_calendar_pcalendar_on_change (GtkTreeView *treeview,
 		return;
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
-	if (!selection ||
-	    !gtk_tree_selection_get_selected (selection, &model, &iter))
-		return;
+	gtk_tree_selection_get_selected (selection, &model, &iter);
 
 	gtk_tree_model_get (model, &iter, CALENDARRURI_COL, &ruri, -1);
 	es_ruri = g_strconcat (account->account_filename, "/;", ruri, NULL);
